﻿using StubContext;

namespace EFConsole
{
    class Program
    {
        static void Main(string[] args)
        {
            Console.OutputEncoding = System.Text.Encoding.UTF8;

            try
            {
                using (AppContext.AppContext db = new StubAppContext())
                {
                    TestUserMethods(db);
                    TestTacticMethods(db);
                    db.SaveChanges();
                }
            }
            catch (Exception ex)
            {
                Console.WriteLine($"Une erreur s'est produite : {ex.Message}");

                if (ex.InnerException != null)
                {
                    Console.WriteLine($"Détails de l'exception interne : {ex.InnerException.Message}");
                }
            }
        }

        static void TestUserMethods(AppContext.AppContext db)
        {
            UsersConsole.TestAddUser(db);
            UsersConsole.TestGetAllUsers(db);
            UsersConsole.TestFindUserByMail(db, "maxime@mail.com");
            UsersConsole.TestUpdateUser(db);
            UsersConsole.TestDeleteUser(db);
            UsersConsole.TestSearchUsersByName(db, "Pierre");
            UsersConsole.TestGetTacticsOfAllUsers(db);
            UsersConsole.TestGetTacticsOfOneUser(db, 1);
        }

        static void TestTacticMethods(AppContext.AppContext db)
        {
            TacticsConsole.TestAddTactic(db);
            TacticsConsole.TestGetAllTactics(db);
            TacticsConsole.TestFindTacticById(db, 1);
            TacticsConsole.TestUpdateTactic(db, 1, "Nouveau nom");
            TacticsConsole.TestDeleteTactic(db, 1);
            TacticsConsole.TestGetTacticsByOwner(db, 1);
        }

    }
}